@@ -286,7 +286,14 @@ api_info = {
                                                 {"Action": "CreateLiveStreamRecordIndexFiles",
                                                  "Version": LIVE_SERVICE_VERSION}, {},
                                                 {}),
-
+    "DescribeLiveBatchPushStreamMetrics": ApiInfo("POST", "/",
+                                                {"Action": "DescribeLiveBatchPushStreamMetrics",
+                                                 "Version": LIVE_SERVICE_VERSION}, {},
+                                                {}),
+    "DescribeLiveBatchSourceStreamMetrics": ApiInfo("POST", "/",
+                                                {"Action": "DescribeLiveBatchSourceStreamMetrics",
+                                                 "Version": LIVE_SERVICE_VERSION}, {},
+                                                {}),
 }
 
 
@@ -787,12 +794,21 @@ class LiveService(Service):
 
     def describe_live_stream_info_by_page(self, request):
         try:
-            params = MessageToDict(request, False, True)
-            for k, v in params.items():
-                if isinstance(v, (int, float, bool, str, unicode)) is True:
-                    continue
-                else:
-                    params[k] = json.dumps(v)
+            if sys.version_info[0] == 3:
+                jsonData = MessageToJson(request, False, True)
+                params = json.loads(jsonData)
+                for k, v in params.items():
+                    if isinstance(v, (int, float, bool, str)) is True:
+                        continue
+                    else:
+                        params[k] = json.dumps(v)
+            else:
+                params = MessageToDict(request, False, True)
+                for k, v in params.items():
+                    if isinstance(v, (int, float, bool, str, unicode)) is True:
+                        continue
+                    else:
+                        params[k] = json.dumps(v)
             res = self.get("DescribeLiveStreamInfoByPage", params)
         except Exception as Argument:
             try:
@@ -1160,3 +1176,19 @@ class LiveService(Service):
             raise Exception("%s: empty response" % action)
         res_json = json.loads(res)
         return res_json
+
+    def describe_live_batch_push_stream_metrics(self, params):
+        action = "DescribeLiveBatchPushStreamMetrics"
+        res = self.json(action, dict(), json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
+
+    def describe_live_batch_source_stream_metrics(self, params):
+        action = "DescribeLiveBatchSourceStreamMetrics"
+        res = self.json(action, dict(), json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
